@@ -2,7 +2,7 @@
 package BerkeleyDB;
 
 
-#     Copyright (c) 1997-2006 Paul Marquess. All rights reserved.
+#     Copyright (c) 1997-2007 Paul Marquess. All rights reserved.
 #     This program is free software; you can redistribute it and/or
 #     modify it under the same terms as Perl itself.
 #
@@ -17,7 +17,7 @@ use Carp;
 use vars qw($VERSION @ISA @EXPORT $AUTOLOAD
 		$use_XSLoader);
 
-$VERSION = '0.31';
+$VERSION = '0.32';
 
 require Exporter;
 #require DynaLoader;
@@ -64,6 +64,7 @@ BEGIN {
 	DB_CHECKPOINT
 	DB_CHKSUM
 	DB_CHKSUM_SHA1
+	DB_CKP_INTERNAL
 	DB_CLIENT
 	DB_CL_WRITER
 	DB_COMMIT
@@ -82,6 +83,7 @@ BEGIN {
 	DB_DIRECT_LOG
 	DB_DIRTY_READ
 	DB_DONOTINDEX
+	DB_DSYNC_DB
 	DB_DSYNC_LOG
 	DB_DUP
 	DB_DUPCURSOR
@@ -99,6 +101,7 @@ BEGIN {
 	DB_ENV_DBLOCAL
 	DB_ENV_DIRECT_DB
 	DB_ENV_DIRECT_LOG
+	DB_ENV_DSYNC_DB
 	DB_ENV_DSYNC_LOG
 	DB_ENV_FATAL
 	DB_ENV_LOCKDOWN
@@ -106,13 +109,17 @@ BEGIN {
 	DB_ENV_LOGGING
 	DB_ENV_LOG_AUTOREMOVE
 	DB_ENV_LOG_INMEMORY
+	DB_ENV_MULTIVERSION
 	DB_ENV_NOLOCKING
 	DB_ENV_NOMMAP
 	DB_ENV_NOPANIC
+	DB_ENV_NO_OUTPUT_SET
 	DB_ENV_OPEN_CALLED
 	DB_ENV_OVERWRITE
 	DB_ENV_PANIC_OK
 	DB_ENV_PRIVATE
+	DB_ENV_RECOVER_FATAL
+	DB_ENV_REF_COUNTED
 	DB_ENV_REGION_INIT
 	DB_ENV_REP_CLIENT
 	DB_ENV_REP_LOGSONLY
@@ -126,9 +133,21 @@ BEGIN {
 	DB_ENV_TXN
 	DB_ENV_TXN_NOSYNC
 	DB_ENV_TXN_NOT_DURABLE
+	DB_ENV_TXN_NOWAIT
+	DB_ENV_TXN_SNAPSHOT
 	DB_ENV_TXN_WRITE_NOSYNC
 	DB_ENV_USER_ALLOC
 	DB_ENV_YIELDCPU
+	DB_EVENT_NOT_HANDLED
+	DB_EVENT_NO_SUCH_EVENT
+	DB_EVENT_PANIC
+	DB_EVENT_REP_CLIENT
+	DB_EVENT_REP_ELECTED
+	DB_EVENT_REP_MASTER
+	DB_EVENT_REP_NEWMASTER
+	DB_EVENT_REP_PERM_FAILED
+	DB_EVENT_REP_STARTUPDONE
+	DB_EVENT_WRITE_FAILED
 	DB_EXCL
 	DB_EXTENT
 	DB_FAST_STAT
@@ -151,6 +170,7 @@ BEGIN {
 	DB_HASHMAGIC
 	DB_HASHOLDVER
 	DB_HASHVERSION
+	DB_IGNORE_LEASE
 	DB_IMMUTABLE_KEY
 	DB_INCOMPLETE
 	DB_INIT_CDB
@@ -232,6 +252,7 @@ BEGIN {
 	DB_MPOOL_CREATE
 	DB_MPOOL_DIRTY
 	DB_MPOOL_DISCARD
+	DB_MPOOL_EDIT
 	DB_MPOOL_EXTENT
 	DB_MPOOL_FREE
 	DB_MPOOL_LAST
@@ -242,10 +263,13 @@ BEGIN {
 	DB_MPOOL_UNLINK
 	DB_MULTIPLE
 	DB_MULTIPLE_KEY
+	DB_MULTIVERSION
 	DB_MUTEXDEBUG
 	DB_MUTEXLOCKS
 	DB_MUTEX_ALLOCATED
+	DB_MUTEX_LOCKED
 	DB_MUTEX_LOGICAL_LOCK
+	DB_MUTEX_PROCESS_ONLY
 	DB_MUTEX_SELF_BLOCK
 	DB_MUTEX_THREAD
 	DB_NEEDSPLIT
@@ -285,11 +309,13 @@ BEGIN {
 	DB_POSITION
 	DB_POSITIONI
 	DB_PREV
+	DB_PREV_DUP
 	DB_PREV_NODUP
 	DB_PRINTABLE
 	DB_PRIORITY_DEFAULT
 	DB_PRIORITY_HIGH
 	DB_PRIORITY_LOW
+	DB_PRIORITY_UNCHANGED
 	DB_PRIORITY_VERY_HIGH
 	DB_PRIORITY_VERY_LOW
 	DB_PRIVATE
@@ -318,16 +344,42 @@ BEGIN {
 	DB_REGISTERED
 	DB_RENAMEMAGIC
 	DB_RENUMBER
+	DB_REPFLAGS_MASK
+	DB_REPMGR_ACKS_ALL
+	DB_REPMGR_ACKS_ALL_PEERS
+	DB_REPMGR_ACKS_NONE
+	DB_REPMGR_ACKS_ONE
+	DB_REPMGR_ACKS_ONE_PEER
+	DB_REPMGR_ACKS_QUORUM
+	DB_REPMGR_CONNECTED
+	DB_REPMGR_DISCONNECTED
+	DB_REPMGR_PEER
+	DB_REP_ACK_TIMEOUT
 	DB_REP_ANYWHERE
 	DB_REP_BULKOVF
+	DB_REP_CHECKPOINT_DELAY
 	DB_REP_CLIENT
+	DB_REP_CONF_BULK
+	DB_REP_CONF_DELAYCLIENT
+	DB_REP_CONF_NOAUTOINIT
+	DB_REP_CONF_NOWAIT
+	DB_REP_CONNECTION_RETRY
 	DB_REP_CREATE
+	DB_REP_DEFAULT_PRIORITY
 	DB_REP_DUPMASTER
 	DB_REP_EGENCHG
+	DB_REP_ELECTION
+	DB_REP_ELECTION_RETRY
+	DB_REP_ELECTION_TIMEOUT
+	DB_REP_FULL_ELECTION
+	DB_REP_FULL_ELECTION_TIMEOUT
 	DB_REP_HANDLE_DEAD
 	DB_REP_HOLDELECTION
 	DB_REP_IGNORE
 	DB_REP_ISPERM
+	DB_REP_JOIN_FAILURE
+	DB_REP_LEASE_EXPIRED
+	DB_REP_LEASE_TIMEOUT
 	DB_REP_LOCKOUT
 	DB_REP_LOGREADY
 	DB_REP_LOGSONLY
@@ -365,6 +417,7 @@ BEGIN {
 	DB_SET_TXN_NOW
 	DB_SET_TXN_TIMEOUT
 	DB_SNAPSHOT
+	DB_SPARE_FLAG
 	DB_STAT_ALL
 	DB_STAT_CLEAR
 	DB_STAT_LOCK_CONF
@@ -372,6 +425,7 @@ BEGIN {
 	DB_STAT_LOCK_OBJECTS
 	DB_STAT_LOCK_PARAMS
 	DB_STAT_MEMP_HASH
+	DB_STAT_NOERROR
 	DB_STAT_SUBSYSTEM
 	DB_SURPRISE_KID
 	DB_SWAPBYTES
@@ -392,8 +446,10 @@ BEGIN {
 	DB_TEST_PREDESTROY
 	DB_TEST_PREOPEN
 	DB_TEST_PRERENAME
+	DB_TEST_RECYCLE
 	DB_TEST_SUBDB_LOCKS
 	DB_THREAD
+	DB_THREADID_STRLEN
 	DB_TIMEOUT
 	DB_TIME_NOTGRANTED
 	DB_TRUNCATE
@@ -421,17 +477,23 @@ BEGIN {
 	DB_TXN_POPENFILES
 	DB_TXN_PRINT
 	DB_TXN_REDO
+	DB_TXN_SNAPSHOT
 	DB_TXN_SYNC
 	DB_TXN_UNDO
+	DB_TXN_WAIT
 	DB_TXN_WRITE_NOSYNC
 	DB_UNKNOWN
 	DB_UNREF
 	DB_UPDATE_SECONDARY
 	DB_UPGRADE
+	DB_USERCOPY_GETDATA
+	DB_USERCOPY_SETDATA
 	DB_USE_ENVIRON
 	DB_USE_ENVIRON_ROOT
 	DB_VERB_CHKPOINT
 	DB_VERB_DEADLOCK
+	DB_VERB_FILEOPS
+	DB_VERB_FILEOPS_ALL
 	DB_VERB_RECOVERY
 	DB_VERB_REGISTER
 	DB_VERB_REPLICATION
@@ -454,10 +516,6 @@ BEGIN {
 	DB_YIELDCPU
 	DB_debug_FLAG
 	DB_user_BEGIN
-	REP_CONF_AUTOINIT
-	REP_CONF_BULK
-	REP_CONF_DELAYCLIENT
-	REP_CONF_NOWAIT
 	);
 
 sub AUTOLOAD {
